# NLP Feature Extractors SDK for Python

### This package has been tested with Python 3.6, 3.7, 3.8 and 3.9

The NLP Feature Extractors project enables the tabular components in the RAI tools to be applied to Natural Language Processing (NLP)
tasks on unstructured text.

Please see the main documentation website:
https://responsibleaitoolbox.ai/

The open source code can be found here:
https://github.com/microsoft/responsible-ai-widgets
